from django.db import models
from django.conf import settings
from django.contrib.auth.models import User
from django.contrib.sites.models import Site
from django.template.defaultfilters import slugify
from django_countries.fields import CountryField

class Profile(models.Model):
    user = models.OneToOneField(User, on_delete=CASADE)
    other_name = models.CharField(
        max_length=200,
        blank=True,
        null=True,
        help_text=""
    )
    about = models.CharField(
        max_length=200,
        blank=True,
        null=True,
        help_text=""
    )
    employer = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    position = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    gender = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    ethnicity = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    facebook = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    twitter = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    linkedin = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    blog = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    image = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    cover_image = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
    
    def __str__(self):
        return self.user.first_name + ' ' + self.user.last_name


from django.contrib import admin
from mmogo.company.models import Company

class CompanyAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("title",)}

admin.site.register(Company, CompanyAdmin)


from django.contrib import admin
from mptt.admin import DraggableMPTTAdmin
from .models import Category


admin.site.register(
    Category,
    DraggableMPTTAdmin,
    list_display=(
        'tree_actions',
        'indented_title',
    ),
    list_display_links=(
        'indented_title',
    ),
)



from django.shortcuts import render


def index(requests):
    context = {}
    return render(request, 'website/templates/index.html', context )

def about_us(requests):
    context = {}
    return render(request, 'website/templates/about.html', context )


def contact_us(requests):
    context = {}
    return render(request, 'website/templates/contacts.html', context )


from django.db import models
from django.conf import settings
from django.contrib.sites.models import Site
from django.template.defaultfilters import slugify
from mmogo.core.category.models import Category, Tag
from mmogo.core.constants import DEFAULT_STATUS
from django_countries.fields import CountryField
from mmogo.core.models import BaseModel

class Company(BaseModel, models.Model):
	website = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
	email = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
	facebook = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
	twitter = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
	linkedin = models.CharField(
		max_length=200, 
		blank=True, 
		null=True,
		help_text=""
	)
	blog = models.CharField(
		max_length=20, 
		blank=True, 
		null=True,
		help_text=""
	)
	physical_address = models.TextField(
		blank=True, 
		null=True,
		help_text=""
	)
	postal_address = models.TextField(
		blank=True, 
		null=True,
		help_text=""
	)
	founded = models.CharField(
		max_length=50, 
		blank=True, 
		null=True,
		help_text=""
	)
	city = models.CharField(
		max_length=20, 
		blank=True, 
		null=True,
		help_text=""
	)
	province = models.CharField(
		max_length=20, 
		blank=True, 
		null=True,
		help_text=""
	)
	country = CountryField(
		blank_label='(Select Country)'
	)
	can_follow = models.BooleanField(default=False)
	follow_disabled = models.BooleanField(default=False)

	class Meta:
		abstract = True

	def __str__(self):
		if self.subtitle:
			return %s + ' - ' + %s % (self.title, self.subtitle)
		else:
			return %s % (self.title)



from django.shortcuts import render, redirect, get_object_or_404
from django.utils import timezone
from .models import Category


# Create your views here.
# def categories_list(request):
#     categories = Categories.objects.all()
#     return render(request, 'categories/index.html', {'nodes': categories})


def category(request, path, instance):
    print instance
    print path

    children = instance.get_children() if instance else Category.objects.root_nodes()
    return render(request, 'categories/index.html',
                  {'instance': instance, 'children': children})

#
# def category(request, path, instance):
#     print instance
#     print path
#
#     category = instance.get_children() if instance else Categories.objects.root_nodes()
#     return render(request, 'categories/category.html',
#                   {'instance': instance, 'category': category})



from django.db import models
from django.core.urlresolvers import reverse
from mptt.models import MPTTModel, TreeForeignKey
from django.utils.translation import ugettext_lazy as _


class Category(MPTTModel):
    title = models.CharField(
        max_length=255,
        help_text=_("The name of the product.")
    )
    slug = models.SlugField(
        help_text=_("The machine readable name of product")
    )
    subtitle = models.CharField(
        max_length=255,
        blank=True,
        null=True,
        help_text=_("")
    )
    description = models.TextField(
        blank=True,
        null=True,
        help_text=_("")
    )
    parent = TreeForeignKey(
        'self',
        null=True,
        blank=True,
        related_name='children',
        db_index=True
    )
    image = models.ImageField(
        upload_to='categories',
        blank=True
    )

    class MPTTMeta:
        order_insertion_by = ['title']


    def get_absolute_url(self):
        return reverse('category', kwargs={'path': self.get_path()})


    class Meta:
        verbose_name = "Category"
        verbose_name_plural = "Categories"

    def __str__(self):
        if self.subtitle:
            return self.title + ' - ' + self.subtitle
        else:
            return self.title



from setuptools import setup, find_packages

setup(
    name="mmogocms",
    version="0.0.4",
    description="Django custom apps to help you get up and running quickly.",
    long_description="Django custom apps to help you get up and running quickly.",
    author="Mmogo Digital",
    author_email="dev@mmogodigital.com",
    license="BSD",
    test_suite="setuptest.setuptest.SetupTestSuite",
    url="http://github.com/mmogodigital/mmogocms",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "django",
        "django-mptt",
        "django-countries",
        "django-taggit",
        "Pillow",
    ],
    tests_require=[
        "tox"
    ],
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: BSD License",
        "Development Status :: 5 - Production/Stable",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
    ],
)


from django.db import models
from django.conf import settings
from django.contrib.sites.models import Site
from django.template.defaultfilters import slugify
from mmogo.core.categories.models import Category, Tag


class BaseModel(models.Model):
	title = models.CharField(
		max_length=200,
		help_text=""
	)
	slug = models.SlugField()
	subtitle = models.CharField(
		max_length=200, 
		blank=True, 
		null=True, 
		help_text=""
	)
	description = models.TextField(
		blank=True, 
		null=True
	)
	category = models.ManyToManyField(
		Category, 
		blank=True, 
		null=True, 
		help_text=""
	)
	tags = tags = TaggableManager(
		blank=True
	)
	image = models.ImageField(
		blank=True,
        null=True,
	)
	image_source = models.CharField(
		max_length=200,
		blank=True,
		null=True,
		help_text=""
	)
	sites = models.ManyToManyField(
		Site,
		blank=True,
		null=True,
		help_text=""
	)
	owner = models.ForeignKey(
		settings.AUTH_USER_MODEL, 
		related_name='%(app_label)s_%(class)s_user',
		editable=False
	)
	created_at = models.DateTimeField(
		auto_now_add=True,
		editable=False
	)
	updated_at = models.DateTimeField(
		auto_now=True,
		editable=False
	)
	status = models.IntegerField(default=constants.DEFAULT_STATUS)
	can_comment = models.BooleanField(default=False)
	anonymous_comment = models.BooleanField(default=False)
	comment_disabled = models.BooleanField(default=False)
	like_enabled = models.BooleanField(default=False)
	anonymous_like = models.BooleanField(default=False)
	like_disabled = models.BooleanField(default=False)
	future_publish = models.DateTimeField(        
		blank=True,
        null=True,
	)
	future_unpublish = models.DateTimeField(        
		blank=True,
        null=True,
	)
	
	def save(self, *args, **kwargs):
		if self.site is None:
			self.sites = Site.objects.get_current()
		self.slug = slugify(self.title)
		super(BaseModel, self).save(*args, **kwargs)

	class Meta:
		abstract = True

	def __str__(self):
		if self.subtitle:
			return self.title + ' - ' + self.subtitle
		else:
			return '%s' % (self.title)



from django.conf.urls import include, url
from mmogo.website import views


urlpatterns = [
	url(r'^$', views.index, name="index"),
	url(r'^contacts/$', views.contact_us, name="contact_us")),
    url(r'^about/$', views.about_us, name="about_us")),
]



from django.contrib import admin
from mmogo.core.models import BaseModel

class BaseModelAdmin(admin.ModelAdmin):
    prepopulated_fields = {"slug": ("title",)}

	def save_model(self, request, obj, form, change):
        obj.owner = request.user
        obj.save()


admin.site.register(BaseModel, BaseModelAdmin)